@@ -1,7 +1,7 @@
 """Tools for interacting with the DLHub Search Index"""
 
 from mdf_toolbox.globus_search.search_helper import SearchHelper
-from globus_sdk.search import SearchClient
+from globus_sdk import SearchClient
 from warnings import warn
 
 
